## Text to Image Triton Model Examples

These can be used on the fly with minimal or no changes to test deploy text to image models to the Clarifai platform. See the required files section for each model below.

* ### [sd-v1.5 (Stable-Diffusion-v1.5)](./sd-v1.5/)

	Requirements to run tests locally:

	* Download/Clone the [huggingface model](https://huggingface.co/runwayml/stable-diffusion-v1-5) into the **sd-v1.5/1/** directory then start the triton server.
